@@ -47,7 +47,10 @@ class TP_Importer(Excel_Importer):
         "right_est": 45,
         "right_tvod": 49,
         "right_svod": 52,
-        "right_avod": 55,
+        # "right_avod": 55,
+        "premium_est_start": 55,
+        "premium_est_end": 56,
+        "premium_est_price_tier": 57,
         "premium_vod_start": 64,
         "premium_vod_end": 65,
         "premium_vod_price_tier": 66,
@@ -122,6 +125,9 @@ class TP_Importer(Excel_Importer):
         "pricetier_1streprice_itunes_est_sd_ch": 250,
         "pricetier_1streprice_itunes_est_hd_ch": 251,
         "channel_type": 0,  # wird nicht aus Excel gelesen
+        "marketing_commitment_sky": 33,
+        "marketing_commitment_videoload": 34,
+        "pf_specific_id_sky": 121,
     }
 
     def __init__(self, valid_statuses=("ok", "change", "new")):
